/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CbmQaManager.h
/// \brief  Manager task for other QA taska (implementation)
/// \author Sergei Zharko <s.zharko@gsi.de>
/// \since  17.10.2023

#include "CbmQaManager.h"

#include "CbmQaTask.h"
#include "Logger.h"

#include <iomanip>

// ---------------------------------------------------------------------------------------------------------------------
//
CbmQaManager::CbmQaManager(int verbose) : FairTask("CbmQaManager", verbose) {}


// ---------------------------------------------------------------------------------------------------------------------
//
void CbmQaManager::Finish()
{
  using std::left;
  using std::right;
  using std::setw;

  std::map<std::string, std::map<std::string, bool>> qaResults;
  for (auto* task : *(this->GetListOfTasks())) {
    auto* pQaTask = dynamic_cast<CbmQaTask*>(task);
    if (pQaTask) {
      qaResults[std::string(task->GetName())] = pQaTask->Check();
    }
  }

  fStatus = true;
  LOG(info) << fName << ": monitorable status:";
  for (auto& [name, resMap] : qaResults) {
    LOG(info) << name;
    for (auto& [quantity, flag] : resMap) {
      LOG(info) << '\t' << left << setw(40) << quantity << right
                << (flag ? "\e[1;32mpassed\e[0m" : "\e[1;31mfailed\e[0m");
      fStatus &= flag;
    }
  }
}

// ---------------------------------------------------------------------------------------------------------------------
//
InitStatus CbmQaManager::Init()
{
  for (auto* task : *(this->GetListOfTasks())) {
    LOG(info) << "\t- " << task->GetName();
  }

  return kSUCCESS;
}
